; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s
;  Note that if you modify the button remapping scheme here, this character will
; still be able to correctly detect the basic commands of other characters
; complying with the basic command order specified below, as long as their
; buttons haven't been remapped.  But no character (not even one with the same
; remapping scheme, not even another instance of this character) will be able to
; correctly detect this character's commands.  This shouldn't ever result in any
; false positives, but it could delay correct positives, and could erroneously
; make the helper AI activation method trigger a false negative in team simul
; modes, in which case the XOR-ed commands method would be needed to provide
; backup.  But of course, this isn't an issue in any version of Mugen prior to
; version 2002.04.14.

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


; These 11 Single Button and Hold Dir commands must be placed here at the top
; of the CMD, above all other commands, and in the standard order shown here,
; in order for the "Compatibly Partnered" version (9742) of the helper AI
; activation method to work with different partners in simul team mode.
; (When the partner is not compatible, then it's best to just use the regular
; version (9741) and rely on the XOR method for backup in case a human
; partner's input turns off the CPU partner's AI.)
;   (Now, even if you do not intend to give your character any custom AI, it
; would still be nice if you would place the commands at the top of your CMD,
; for the sake of other characters which do use this AI activation method.
; And then, define Anim 9741 in your AIR file to indicate to other characters
; that your character is compatible.
;   It may slightly increase the chances of faulty AI activation if the user
; is using characters with a poor implementation of the old humanly-impossible
; commands AI activation method when fighting against your character, but
; other than that, there's really no particular reason not to.  And you can
; change the names of the commands if you want.  For compatibility, all that
; really matters is the "command" and "time" parameters.)
;
; Please don't add any extra definitions for any of these 11 basic command
; names, nor for any of the 7 "hold[button]" command names that follow.
; For example, things like this should be avoided:
;	[Command]
;	name = "z"
;	command = y+b
;	time = 1
; There are several workarounds possible to achieve the same effect.  Please
; feel free to ask me about it if you have any uncertainty.
; Violating this rule would cause the KeyCtrl Helper method and/or the XORed
; Commands method to malfunction, and could also interfere with other future
; applications of this command order standard.
;
;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

; Here add matching commands for any moves that must never be used randomly
; by the computer, such as suicide moves and super moves, and add the pairs
; to the XOR VarSet controller in State -3.

; If you're desperate to make sure that the AI always gets turned on as soon
; as possible, you can add more equivalents for your own commands here too,
; and add to the XOR VarSet controller's triggers accordingly.

; And of course, if you've run out of unique command labels (Mugen allows
; 128), you can remove as many of these as you want.  You'll of course need
; to modify the XOR VarSet controller's triggers accordingly, but Mugen
; will let you know if you forget to do so. :)


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "Gibberish"
command = ~F,B,F,z
[Command]
name = "Gibberish"
command = ~F,B,F,y
[Command]
name = "Gibberish"
command = ~F,B,F,x

[Command]
name = "SimpleSuper"
command = ~D,DF,F,D,DF,F, x
time = 20
[Command]
name = "SimpleSuper"
command = ~D,DF,F,D,DF,F, y
time = 20
[Command]
name = "SimpleSuper"
command = ~D,DF,F,D,DF,F, z
time = 20
[Command]
name = "SimpleSuper"
command = ~D,F,D,F, x
time = 20
[Command]
name = "SimpleSuper"
command = ~D,F,D,F, y
time = 20
[Command]
name = "SimpleSuper"
command = ~D,F,D,F, z
time = 20

[Command]
name = "RisingSuper"
command = ~D,DF,F,D,DF,F, a
time = 20
[Command]
name = "RisingSuper"
command = ~D,DF,F,D,DF,F, b
time = 20
[Command]
name = "RisingSuper"
command = ~D,DF,F,D,DF,F, c
time = 20
[Command]
name = "RisingSuper"
command = ~D,F,D,F, a
time = 20
[Command]
name = "RisingSuper"
command = ~D,F,D,F, b
time = 20
[Command]
name = "RisingSuper"
command = ~D,F,D,F, c
time = 20

[Command]
name = "Bow"
command = ~D,DB,B,D,DB,B, x
time = 20
[Command]
name = "Bow"
command = ~D,DB,B,D,DB,B, y
time = 20
[Command]
name = "Bow"
command = ~D,DB,B,D,DB,B, z
time = 20
[Command]
name = "Bow"
command = ~D,B,D,B, x
time = 20
[Command]
name = "Bow"
command = ~D,B,D,B, y
time = 20
[Command]
name = "Bow"
command = ~D,B,D,B, z
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x
[Command]
name = "upper_y"
command = ~F, D, DF, y
[Command]
name = "upper_z"
command = ~F, D, DF, z
[Command]
name = "upper_x"
command = ~F, D, F, x
[Command]
name = "upper_y"
command = ~F, D, F, y
[Command]
name = "upper_z"
command = ~F, D, F, z

[Command]
name = "HCB_a"
command = ~F, DF, D, DB, B, a
[Command]
name = "HCB_a"
command = ~F, D, B, a
[Command]
name = "HCB_b"
command = ~F, DF, D, DB, B, b
[Command]
name = "HCB_b"
command = ~F, D, B, b
[Command]
name = "HCB_c"
command = ~F, DF, D, DB, B, c
[Command]
name = "HCB_c"
command = ~F, D, B, c

[Command]
name = "HCF_a"
command = ~B, DB, D, DF, F, a
[Command]
name = "HCF_a"
command = ~B, D, F, a
[Command]
name = "HCF_b"
command = ~B, DB, D, DF, F, b
[Command]
name = "HCF_b"
command = ~B, D, F, b
[Command]
name = "HCF_c"
command = ~B, DB, D, DF, F, c
[Command]
name = "HCF_c"
command = ~B, D, F, c

[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, x
[Command]
name = "HCF_x"
command = ~B, D, F, x
[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, y
[Command]
name = "HCF_y"
command = ~B, D, F, y
[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, z
[Command]
name = "HCF_z"
command = ~B, D, F, z

[Command]
name = "QCB_a"
command = ~D, DB, B, a
[Command]
name = "QCB_b"
command = ~D, DB, B, b
[Command]
name = "QCB_c"
command = ~D, DB, B, c
[Command]
name = "QCB_x"
command = ~D, DB, B, x
[Command]
name = "QCB_y"
command = ~D, DB, B, y
[Command]
name = "QCB_z"
command = ~D, DB, B, z

[Command]
name = "QCB_a"
command = ~D, B, a
[Command]
name = "QCB_b"
command = ~D, B, b
[Command]
name = "QCB_c"
command = ~D, B, c
[Command]
name = "QCB_x"
command = ~D, B, x
[Command]
name = "QCB_y"
command = ~D, B, y
[Command]
name = "QCB_z"
command = ~D, B, z


[Command]
name = "CBF_a"
command = ~15$B, $F, a
time = 10
[Command]
name = "CBF_b"
command = ~15$B, $F, b
time = 10
[Command]
name = "CBF_c"
command = ~15$B, $F, c
time = 10
[Command]
name = "CBF_x"
command = ~15$B, $F, x
time = 10
[Command]
name = "CBF_y"
command = ~15$B, $F, y
time = 10
[Command]
name = "CBF_z"
command = ~15$B, $F, z
time = 10

; N'Edge commands

[Command]
name = "SimpleSuper"
command = ~D,DF,F,D,DF,F, ~x
time = 20
[Command]
name = "SimpleSuper"
command = ~D,DF,F,D,DF,F, ~y
time = 20
[Command]
name = "SimpleSuper"
command = ~D,DF,F,D,DF,F, ~z
time = 20
[Command]
name = "SimpleSuper"
command = ~D,F,D,F, ~x
time = 20
[Command]
name = "SimpleSuper"
command = ~D,F,D,F, ~y
time = 20
[Command]
name = "SimpleSuper"
command = ~D,F,D,F, ~z
time = 20

[Command]
name = "RisingSuper"
command = ~D,DF,F,D,DF,F, ~a
time = 20
[Command]
name = "RisingSuper"
command = ~D,DF,F,D,DF,F, ~b
time = 20
[Command]
name = "RisingSuper"
command = ~D,DF,F,D,DF,F, ~c
time = 20
[Command]
name = "RisingSuper"
command = ~D,F,D,F, ~a
time = 20
[Command]
name = "RisingSuper"
command = ~D,F,D,F, ~b
time = 20
[Command]
name = "RisingSuper"
command = ~D,F,D,F, ~c
time = 20

[Command]
name = "Bow"
command = ~D,DB,B,D,DB,B, ~x
time = 20
[Command]
name = "Bow"
command = ~D,DB,B,D,DB,B, ~y
time = 20
[Command]
name = "Bow"
command = ~D,DB,B,D,DB,B, ~z
time = 20
[Command]
name = "Bow"
command = ~D,B,D,B, ~x
time = 20
[Command]
name = "Bow"
command = ~D,B,D,B, ~y
time = 20
[Command]
name = "Bow"
command = ~D,B,D,B, ~z
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, ~x
[Command]
name = "upper_y"
command = ~F, D, DF, ~y
[Command]
name = "upper_z"
command = ~F, D, DF, ~z
[Command]
name = "upper_x"
command = ~F, D, F, ~x
[Command]
name = "upper_y"
command = ~F, D, F, ~y
[Command]
name = "upper_z"
command = ~F, D, F, ~z

[Command]
name = "HCB_a"
command = ~F, DF, D, DB, B, ~a
[Command]
name = "HCB_a"
command = ~F, D, B, ~a
[Command]
name = "HCB_b"
command = ~F, DF, D, DB, B, ~b
[Command]
name = "HCB_b"
command = ~F, D, B, ~b
[Command]
name = "HCB_c"
command = ~F, DF, D, DB, B, ~c
[Command]
name = "HCB_c"
command = ~F, D, B, ~c

[Command]
name = "HCF_a"
command = ~B, DB, D, DF, F, ~a
[Command]
name = "HCF_a"
command = ~B, D, F, ~a
[Command]
name = "HCF_b"
command = ~B, DB, D, DF, F, ~b
[Command]
name = "HCF_b"
command = ~B, D, F, ~b
[Command]
name = "HCF_c"
command = ~B, DB, D, DF, F, ~c
[Command]
name = "HCF_c"
command = ~B, D, F, ~c

[Command]
name = "HCF_x"
command = ~B, DB, D, DF, F, ~x
[Command]
name = "HCF_x"
command = ~B, D, F, ~x
[Command]
name = "HCF_y"
command = ~B, DB, D, DF, F, ~y
[Command]
name = "HCF_y"
command = ~B, D, F, ~y
[Command]
name = "HCF_z"
command = ~B, DB, D, DF, F, ~z
[Command]
name = "HCF_z"
command = ~B, D, F, ~z

[Command]
name = "QCB_a"
command = ~D, DB, B, ~a
[Command]
name = "QCB_b"
command = ~D, DB, B, ~b
[Command]
name = "QCB_c"
command = ~D, DB, B, ~c
[Command]
name = "QCB_x"
command = ~D, DB, B, ~x
[Command]
name = "QCB_y"
command = ~D, DB, B, ~y
[Command]
name = "QCB_z"
command = ~D, DB, B, ~z

[Command]
name = "QCB_a"
command = ~D, B, ~a
[Command]
name = "QCB_b"
command = ~D, B, ~b
[Command]
name = "QCB_c"
command = ~D, B, ~c
[Command]
name = "QCB_x"
command = ~D, B, ~x
[Command]
name = "QCB_y"
command = ~D, B, ~y
[Command]
name = "QCB_z"
command = ~D, B, ~z


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

; This is generally the best place to put most of your AI directives.  For
; example, this controller would only be executed when the CPU is in control:
;
; [State -1, Haha!]
; type = ChangeState
; trigger1 = var(0) ; (Or use "var(58)>0" if you've chosen not to
;                   ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType = S
; trigger1 = MoveType = I
; trigger1 = P2MoveType = H
; trigger1 = NumEnemy = 1
; trigger1 = Enemy,GetHitVar(HitTime) > 60
; trigger1 = PrevStateNo != 195
; trigger1 = Random < 99
; value = 195

; And of course, most human-only command-based ChangeStates also belong
; in State -1.  For example, this move would only be performable by a human:
;
; [State -1, Death Before Dishonor]
; type = ChangeState
; trigger1 = command = "suicide"
; trigger1 = !var(0) ; (Or use "var(58)<1" if you've chosen not to
;                    ; use the Simplifier variable/controller.)
; trigger1 = ctrl
; trigger1 = StateType != A
; trigger1 = MoveType = I
; value = {suicide state number}


;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = (stateno != 255 && stateno != 225 && stateno != 220 && stateno != 245) || animtime >= -10
trigger2 = movecontact
var(9) = 1

;===========================================================================
;AI
;===========================================================================

[State AI, Kung Fu Throw]
type = ChangeState
value = ifelse(random<100,40,ifelse(random<100,1310,800))
triggerall = var(55)
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = stateno != 40
triggerall = random < 900 || var(54) = 2
triggerall = p2stateno != [5100,5200]
triggerall = prevstateno != [800,899]
;triggerall = var(8) <= 0
trigger1 = p2bodydist X <= 5
trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H

[State AI, ChangeState]
type = ChangeState
triggerall = stateno != 40
triggerall = var(54) != 1
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = 130;ifelse(random<10&&(stateno!=[120,169])&&p2bodydist x<=35&&(enemynear,animtime<=-5)&&var(42)<=-33,400,130)

[State AI, ChangeState]
type = ChangeState
triggerall = stateno != 40
triggerall = var(54) != 1
triggerall = (var(55)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<16&&(stateno!=[120,169]),40,131)

[State AI, Taunt]
type = ChangeState
triggerall = var(55)
triggerall = p2bodydist x >= 80
triggerall = statetype != A
triggerall = prevstateno != 195
triggerall = stateno != 195
triggerall = ctrl
trigger1 = random < ifelse(p2bodydist x<=45,500,20)
trigger1 = (p2stateno = [5100,5200]) || p2statetype = L
value = 195

[State AI, ANTI-AIR]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5100,5130]
;triggerall = p2bodydist x = [-5,85]
triggerall = p2bodydist y = [-192,-58]
triggerall = random < 500
triggerall = stateno != 20
triggerall = stateno != 40
triggerall = stateno != 100
trigger1 = ctrl
value = ifelse( random<250&&p2bodydist x<=55&&power>=1000 , 3050 , ifelse( p2bodydist x > 85 , ifelse(random<500,1110,1120) , ifelse(random<100,1020,ifelse(random<222,1310,1320)) ) )
;value = ifelse(random<100,430,ifelse(random<222,1000,ifelse(random<150&&power>=1000,3100,400)))

[State AI, Simple Attack]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing || (enemynear,HitDefAttr = SCA,NT,ST,HT))
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x = [-5,38]
triggerall = p2bodydist y >= -135
triggerall = random < 500 || numtarget
triggerall = stateno != 20 || random < 200
triggerall = stateno != 40
triggerall = stateno != 100
trigger1 = ctrl
value = ifelse( random < 50, 1000 , ifelse(random<500,200,210) + ifelse(random<222,30,0) + ifelse(random<150||p2statetype=C,200,ifelse(random<500,5,0)) )

[State AI, Simple Attack]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing || (enemynear,HitDefAttr = SCA,NT,ST,HT))
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x = [20,48]
triggerall = p2bodydist y >= -135
triggerall = random < 400 || numtarget
triggerall = stateno != 20 || random < 200
triggerall = stateno != 40
triggerall = stateno != 100
trigger1 = ctrl
value = ifelse(random<500,220,ifelse(random<500,230,240)) + ifelse(random<200,200,0)

[State AI, Simple Attack]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing || (enemynear,HitDefAttr = SCA,NT,ST,HT))
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x = [35,70]
triggerall = p2bodydist y >= -120
triggerall = random < 300 || numtarget
triggerall = stateno != 20 || random < 200
triggerall = stateno != 40
triggerall = stateno != 100
trigger1 = ctrl
value = ifelse( random < 100 , 1050 , ifelse(random<333,ifelse(random<200,252,250), ifelse(random<200,255,ifelse(random<500,235,215)) ) )

[State AI, Simple Attack]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing || (enemynear,HitDefAttr = SCA,NT,ST,HT))
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x = [45,90]
triggerall = p2bodydist y >= -115
triggerall = random < 300 || numtarget
triggerall = stateno != 20 || random < 150
triggerall = stateno != 40
triggerall = stateno != 100
trigger1 = ctrl
value = ifelse( random < 100 , 1060 , ifelse(random<333,450, ifelse(random<200,245,225) ) )

[State AI, After Land Poke]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded != [1,8]) || (enemynear,HitDefAttr = SCA,AT) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x <= 87
triggerall = random < 140 + floor( abs(life - p2life) / 4)
triggerall = p2movetype != H || random < 500
trigger1 = stateno = 52
trigger1 = animtime = 0
value = ifelse( p2bodydist x <= 55, ifelse(random<200,250,1010), ifelse(random<200,ifelse(random<500,450,1310),100) )

[State AI, Far Attack]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x = [65,120]
triggerall = p2bodydist y >= -115
triggerall = random < 300 || numtarget
triggerall = stateno != 20 || random < 350
triggerall = stateno != 40
triggerall = stateno != 100
trigger1 = ctrl
value = ifelse( random < 180 , ifelse(random<222&&power>=1000,ifelse(p2bodydist x<=45,3050,3000),1070) , ifelse(random<333,1110, ifelse(random<200&&p2statetype!=A,ifelse(random<500,1210,1260),1300) ) )

[State AI, CHARGE ME]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
;triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x = [70,153]
triggerall = p2bodydist y >= -115
triggerall = random < 222
triggerall = p2statetype!=A
triggerall = p2statetype!=L
trigger1 = stateno = 20
trigger1 = anim = 21
trigger1 = time >= 8
trigger2 = prevstateno = 140
trigger2 = ctrl
trigger3 = stateno = 220 || stateno = 225 || stateno = 255 || stateno = 240 || stateno = 215 || stateno = 420 || stateno = 450 || stateno = 1100 || stateno = 1110
trigger3 = animtime = 0
value = ifelse( random<=100&&power >=1000&&(p2stateno!=[120,169]), ifelse((random<200&&(p2bodydist x<=50 + abs(p2bodydist y/3)))||p2bodydist x<=50,3050,3000) , ifelse(random<500,1210,1260) )

;[State AI, Far Attack]
;type = ChangeState
;triggerall = var(55)
;triggerall = statetype != A
;triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
;triggerall = p2stateno != [5100,5130]
;triggerall = p2bodydist x = [15,103]
;triggerall = p2bodydist y >= -155
;triggerall = random < 300
;triggerall = stateno != 20 || random < 200
;triggerall = stateno != 40
;triggerall = stateno != 100
;trigger1 = ctrl
;value = ifelse(random<200&&p2bodydist x>=40,100,ifelse(random<500&&p2bodydist x<=88&&var(42)<=-85,210,ifelse(random<200,430,230)) )

;[State AI, Faaaar Attack]
;type = ChangeState
;triggerall = var(55)
;triggerall = statetype != A
;triggerall = (p2movetype != A || EnemyNear, Facing = Facing)
;triggerall = p2stateno != [5100,5130]
;triggerall = p2bodydist x = [50,189]
;triggerall = p2bodydist y >= -155
;triggerall = random < 100
;triggerall = stateno != 20 || random < 100
;triggerall = stateno != 40
;triggerall = stateno != 100
;trigger1 = ctrl
;value = ifelse(random<200||p2bodydist x>=139,100,ifelse(random<800,430,1000))

;[State AI, SHORYU COMBO]
;type = ChangeState
;value = ifelse(stateno=230&&random<100,800,ifelse(random<150&&power>=1000,3100,400))
;triggerall = var(55)
;triggerall = movehit
;triggerall = random < 350
;triggerall = p2bodydist x = [-15,55]
;trigger1 = stateno = 230
;trigger1 = animelemtime(10) >= 3
;trigger1 = random < 100
;trigger2 = stateno = 430
;trigger2 = animelemtime(4) >= 3
;trigger3 = stateno = 205
;trigger3 = animelemtime(3) > 3

[State AI, JUMP-IN]
type = ChangeState
triggerall = var(55)
triggerall = statetype = A
;triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded != [1,8]) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5100,5130]
triggerall = p2bodydist x = [-25,49]
triggerall = p2bodydist y = [-111,70]
triggerall = random < 500
triggerall = vel y >= 0 || p2statetype = A
trigger1 = ctrl
value = ifelse(random<100, ifelse(random<500,1150,1360) , ifelse(random<500,620,650))

[State AI, DO SOMETHING]
type = ChangeState
value = ifelse(random<420&&power>=1000,3150,811+random%3)
triggerall = var(55)
triggerall = stateno = 810
trigger1 = random < 66
trigger1 = animelemtime(2) > 8
trigger1 = animelemtime(3) < 0
trigger2 = animelemtime(3) = -1

[State AI, POWER]
type = ChangeState
value = ifelse((random<200&&(p2bodydist x<=45 + abs(p2bodydist y/3)))||p2bodydist x<=35,3050,3000)
triggerall = var(55)
triggerall = random < 100
triggerall = power >= 1000
triggerall = p2bodydist x <= 135
triggerall = stateno != 20
triggerall = stateno != 40
triggerall = p2stateno != [120,162]
triggerall = p2stateno != [5080,5120]
triggerall = (enemynear, statetype != L) && (enemynear, movetype != A) && (enemynear, ctrl = 0)
trigger1 = var(9)
trigger2 = stateno = 1000 || stateno = 1010 || stateno = 1020
trigger2 = animtime >= -10
trigger3 = stateno = 1100 || stateno = 1110
trigger3 = animtime >= -7

[State AI, BOW]
type = ChangeState
value = 3100
triggerall = var(55)
triggerall = random < 100
triggerall = power >= 1000
triggerall = p2bodydist x >= 100
triggerall = stateno != 20
triggerall = stateno != 40
triggerall = !numhelper(3100)
triggerall = p2stateno != [120,162]
triggerall = (enemynear, statetype != L) && (enemynear, movetype != A) && (enemynear, ctrl = 0)
trigger1 = var(9)
trigger2 = stateno = 1000 || stateno = 1010 || stateno = 1020
trigger2 = animtime >= -10
trigger3 = stateno = 1100 || stateno = 1110
trigger3 = animtime >= -7

[State AI, JUST ADVANCE]
type = ChangeState
value = ifelse( random<100&&command="holdfwd" , 40 , ifelse(p2bodydist x<=130&&random<200,1300,100) )
triggerall = var(55)
triggerall = random < 350
triggerall = p2bodydist x >= 75
triggerall = stateno != 20
triggerall = stateno != 40
triggerall = (enemynear, statetype != L) && (enemynear, movetype != A) && (enemynear, ctrl = 0)
trigger1 = statetype = S
trigger1 = ctrl

[State AI, COMBO FORM S.LP]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = p2statetype != A
trigger1 = stateno = 200 || stateno = 205
trigger1 = movehit
value = ifelse(random<200||p2bodydist x>=42,ifelse(random<200||p2statetype=C,450,225),ifelse(random<100||p2statetype=C,ifelse(random<500,420,440),ifelse(random<500,210,215)))

[State AI, COMBO FROM C.LP]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = p2statetype != A
trigger1 = stateno = 400
trigger1 = movehit
value = ifelse(random<200||p2bodydist x>=45,450,ifelse(random<500,420,440))

[State AI, COMBO S.MP]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = p2statetype != A
trigger1 = stateno = 210 || stateno = 215 || stateno = 235
trigger1 = movehit
value = ifelse(random<500&&p2bodydist x<=50,255,ifelse(random<150,1300,1020))

[State AI, COMBO INTO A SPECIAL]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
trigger1 = var(9)
trigger1 = movehit
trigger1 = animtime >= -10
value = ifelse(random<150&&p2bodydist x<60,1020,ifelse(random<100&&p2statetype!=A,ifelse(random<500||p2statetype=S,1200,1250),ifelse(p2bodydist x<=60,1310,1100)))

[State AI, BREAKAUP]
type = ChangeState
triggerall = var(55)
triggerall = statetype != A
triggerall = random < 140
triggerall = p2statetype != A
trigger1 = var(9)
trigger1 = moveguarded
trigger1 = animtime >= -10
value = ifelse(random<500||p2statetype=S,1200,1250) + ifelse(p2bodydist x<=90,0,ifelse(p2bodydist x>=120,20,10))


;===========================================================================
;END OF AI
;===========================================================================

; NOW THAT'S JUST OVERKILL
[State -1, Simplest Super Ever]
type = ChangeState
value = 3000
triggerall = command = "SimpleSuper"
triggerall = power >= 1000
trigger1 = var(9)
trigger2 = stateno = 1000 || stateno = 1010 || stateno = 1020
trigger2 = animtime >= -10
trigger3 = stateno = 1100 || stateno = 1110
trigger3 = animtime >= -7

; NOW THAT'S JUST OVERKILL
[State -1, Air/Leg Grapple Combo]
type = ChangeState
value = 3050
triggerall = (command = "RisingSuper" && !var(55))
triggerall = power >= 1000
trigger1 = var(9)
trigger2 = stateno = 1000 || stateno = 1010 || stateno = 1020
trigger2 = animtime >= -10
trigger3 = stateno = 1100 || stateno = 1110
trigger3 = animtime >= -7

; NOW THAT'S JUST OVERKILL
[State -1, Botched Spriting Go!]
type = ChangeState
value = 3100
triggerall = command = "Bow"
triggerall = power >= 1000
triggerall = !numhelper(3100)
trigger1 = var(9)
trigger2 = stateno = 1000 || stateno = 1010 || stateno = 1020
trigger2 = animtime >= -10
trigger3 = stateno = 1100 || stateno = 1110
trigger3 = animtime >= -7

; DP+X
[State -1, Air Grapple]
type = ChangeState
value = 1300
triggerall = command = "upper_x"
trigger1 = var(9)
;trigger1 = (stateno != 230 && stateno != 240) || animtime >= -5
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; DP+Y
[State -1, Air Grapple]
type = ChangeState
value = 1310
triggerall = command = "upper_y"
trigger1 = var(9)
;trigger1 = (stateno != 230 && stateno != 240) || animtime >= -5
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; DP+Z
[State -1, Air Grapple]
type = ChangeState
value = 1320
triggerall = command = "upper_z"
trigger1 = var(9)
;trigger1 = (stateno != 230 && stateno != 240) || animtime >= -5
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; HCB+A
[State -1, Kangaroo Kick]
type = ChangeState
value = 1100
triggerall = command = "HCB_a"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; HCB+A
[State -1, Kangaroo Kick]
type = ChangeState
value = 1110
triggerall = command = "HCB_b"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; HCB+A
[State -1, Kangaroo Kick]
type = ChangeState
value = 1120
triggerall = command = "HCB_c"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; CBF+A
[State -1, Leg Grapple]
type = ChangeState
value = 1200
triggerall = command = "HCF_a"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -12

; CBF+B
[State -1, Leg Grapple]
type = ChangeState
value = 1210
triggerall = command = "HCF_b"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -12

; CBF+C
[State -1, Leg Grapple]
type = ChangeState
value = 1220
triggerall = command = "HCF_c"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -12

; CBF+X
[State -1, Punch Grapple 1]
type = ChangeState
value = 1250
triggerall = command = "HCF_x"
trigger1 = var(9)
;trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -5

; CBF+X
[State -1, Punch Grapple 2]
type = ChangeState
value = 1260
triggerall = command = "HCF_y"
trigger1 = var(9)
;trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -5

; CBF+X
[State -1, Punch Grapple 3]
type = ChangeState
value = 1270
triggerall = command = "HCF_z"
trigger1 = var(9)
;trigger1 = (stateno != 230 && stateno != 240 && stateno != 250 && stateno != 235) || animtime >= -5

; QCB+A
[State -1, Special Kick]
type = ChangeState
value = 1000
triggerall = command = "QCB_a"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; QCB+A
[State -1, Special Kick]
type = ChangeState
value = 1010
triggerall = command = "QCB_b"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; QCB+A
[State -1, Special Kick]
type = ChangeState
value = 1020
triggerall = command = "QCB_c"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240) || animtime >= -10
trigger2 = stateno = 1050 || stateno = 1060 || stateno = 1070
trigger2 = animtime >= -10

; QCB+X
[State -1, Special Punch]
type = ChangeState
value = 1050
triggerall = command = "QCB_x"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240) || animtime >= -10

[State -1, Special Punch]
type = ChangeState
value = 1060
triggerall = command = "QCB_y"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240) || animtime >= -10

[State -1, Special Punch]
type = ChangeState
value = 1070
triggerall = command = "QCB_z"
trigger1 = var(9)
trigger1 = (stateno != 230 && stateno != 240) || animtime >= -10

; QCB+A
[State -1, Air Special Kicks]
type = ChangeState
value = 1150
triggerall = command = "QCB_a" || command = "QCB_b" || command = "QCB_c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620
trigger2 = movecontact

; QCB+A
[State -1, Air Special Punche]
type = ChangeState
value = 1350
triggerall = command = "QCB_x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 630
trigger2 = movecontact

; QCB+A
[State -1, Air Special Punche]
type = ChangeState
value = 1360
triggerall = command = "QCB_y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 630
trigger2 = movecontact

; QCB+A
[State -1, Air Special Punche]
type = ChangeState
value = 1370
triggerall = command = "QCB_z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 610 || stateno = 620 || stateno = 630
trigger2 = movecontact

;===========================================================================

;===========================================================================

[State -1, Gibberish]
type = ChangeState
value = 3150
triggerall = command = "Gibberish"
triggerall = stateno = 810
triggerall = power >= 1000
trigger1 = animelemtime(2) > 0
trigger1 = animelemtime(3) < 0

;
[State -1, Kick]
type = ChangeState
value = 814
triggerall = command = "holdfwd"
triggerall = command = "a" || command = "b" || command = "c"
triggerall = stateno = 810
trigger1 = animelemtime(2) > 0
trigger1 = animelemtime(3) < 0

;
[State -1, Slam]
type = ChangeState
value = 813
triggerall = command = "holddown"
triggerall = command = "x" || command = "y" || command = "z"
triggerall = stateno = 810
trigger1 = animelemtime(2) > 0
trigger1 = animelemtime(3) < 0

;
[State -1, Throw]
type = ChangeState
value = 811
triggerall = command != "holddown"
triggerall = command = "x" || command = "y" || command = "z"
triggerall = stateno = 810
trigger1 = animelemtime(2) > 0
trigger1 = animelemtime(3) < 0

;
[State -1, Knee]
type = ChangeState
value = 812
triggerall = command != "holdfwd"
triggerall = command = "a" || command = "b" || command = "c"
triggerall = stateno = 810
trigger1 = animelemtime(2) > 0
trigger1 = animelemtime(3) < 0


;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = stateno != 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
;[State -1, Run Back]
;type = ChangeState
;value = 105
;trigger1 = command = "BB"
;trigger1 = statetype = S
;trigger1 = ctrl

[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y" || command = "z"
triggerall = command = "holdfwd" || command = "holdback"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
;triggerall = var(8) = 0
trigger1 = p2bodydist X < 5
trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H



;===========================================================================
;---------------------------------------------------------------------------
[State -1, Standing Light Punch]
type = ChangeState
value = 205
triggerall = command = "x"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Standing Medium Punch]
type = ChangeState
value = 215
triggerall = command = "y"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 230 || stateno = 205
trigger2 = animtime >= -7 || movecontact

[State -1, Standing Hard Punch]
type = ChangeState
value = 225
triggerall = command = "z"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = animtime >= -7 || movecontact

[State -1, Forward Light Kick]
type = ChangeState
value = 235
triggerall = command = "a"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 205
trigger2 = animtime >= -7 || movecontact

[State -1, Forward Medium Kick]
type = ChangeState
value = 245
triggerall = command = "b"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 205
trigger2 = animtime >= -7 || movecontact

[State -1, Forward Hard Kick]
type = ChangeState
value = 255
triggerall = command = "c"
triggerall = command = "holdfwd"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 215 || stateno = 205 || stateno = 210 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440 || stateno = 235
trigger2 = animtime >= -7 || movecontact

[State -1, Backward Sweep Kick]
type = ChangeState
value = 252
triggerall = command = "c"
triggerall = command = "holdback"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 215 || stateno = 205 || stateno = 210 || stateno = 400 || stateno = 410
trigger2 = animtime >= -7 || movecontact

;---------------------------------------------------------------------------
[State -1, Standing Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = animtime >= -7 || movecontact

[State -1, Standing Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = animtime >= -7 || movecontact

[State -1, Standing Hard Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = animtime >= -7 || movecontact

[State -1, Standing Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Standing Hard Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;...
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
triggerall = stateno != 195
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 200
trigger2 = animtime >= -7 || movecontact

[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 200
trigger2 = animtime >= -7 || movecontact

[State -1, Crouching Hard Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400
trigger2 = animtime >= -7 || movecontact

[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 200 || stateno = 205
trigger2 = animtime >= -7 || movecontact

[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 200 || stateno = 205
trigger2 = animtime >= -7 || movecontact

[State -1, Crouching Hard Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 200 || stateno = 205
trigger2 = animtime >= -7 || movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Kick]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl


